==> groupoffice-com-4.0.47.tar.gz: groupoffice-com-4.0.47/modules/addressbook/language/nb.php <==
<?php




$l['name'] = 'Adressebok';
$l['description'] = 'Modul for å håndtere alle kontakter.';
$l['allAddressbooks'] = 'Alle adressebøker';
$l['notIncluded'] = 'Ikke importer';
$l['comment'] = 'Kommentar';
$l['bankNo'] = 'Bankkonto'; ;
$l['vatNo'] = 'Org.nr.';
$l['contactsGroup'] = 'Gruppe';
$l['customers'] = 'Kunder';
$l['suppliers'] = 'Leverandører';
$l['prospects'] = 'Prospekter';
$l['contacts'] = 'Kontaktpersoner';
$l['companies'] = 'Firmaer';
$l['newContactAdded']='Ny kontaktperson er lagt til';
$l['newContactFromSite']='En ny kontaktperson er lagt til via et nettstedskjema.';
$l['clickHereToView']='Trykk her for å vise kontakpersonen';
$l['contactFromAddressbook']='Kontaktperson fra %s';
$l['companyFromAddressbook']='Firma fra %s';
$l['multipleSelected']='Flere adressebøker er valgt';
$l['incomplete_delete_contacts']='Du har ikke rettigheter til å slette alle valgte kontaktpersoner';
$l['incomplete_delete_companies']='Du har ikke rettigheter til å slette alle valgte firmaer';
$l['emailAlreadyExists']='E-postadressen er allerede lagret på denne kontaktpersonen';
$l['emailDoesntExists']='Fant ikke e-postadressen';
$l['imageNotSupported']='Bildefilen du lastet opp er ikke støttet. Bare gif, png og jpg er gyldige filtyper.';
$l["selectMailingGroup"]='Velg gruppe for masseutsendelse';
$l["cmdFormLabelAddressBooks"]= 'Adressebok';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,Æ,Ø,Å';
$l["cmdAllFields"]= 'Alle felt';
$l["btnAddContact"]= 'Ny kontaktperson'	;
$l["btnAddCompany"]= 'Nytt firma';
$l["btnManage"]= 'Behandle';
$l["btnDownload"]= 'Last ned fil';
$l["cmdFormSearchFirst"]= 'Søk i= ';
$l["cmdFormSearchSecond"]= ' på= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Bruk \'%\' som jokertegn) ';
$l["cmdFormLabelTitleInitials"]= 'Tittel/initialer';
$l["cmdFormLabelSalutation"]= 'Hilsning';
$l["cmdFormLabelComment"]= 'Kommentarer';
$l["cmdFormCompanyEmptyText"]= 'Velg et firma';
$l["cmdFieldsetSelectAddressbook"]= 'Velg adressebok';
$l["cmdFieldsetPersonalDetails"]= 'Personlige opplysninger';
$l["cmdFieldsetAddress"]= 'Adresse';
$l["cmdFieldsetContact"]= 'Kontaktopplysninger';
$l["cmdFieldsetWork"]= 'Arbeid';
$l["cmdPanelContact"]= 'Kontaktopplysninger';
$l["cmdPanelComments"]= 'Kommentarer';
$l["cmdContactDialog"]= 'Rediger kontaktperson';
$l["contact"]= 'Kontaktperson';
$l["cmdSalutation"]= 'Kjære';
$l["cmdMadam"]= 'fr.';
$l["cmdSir"]= 'herr';
$l["btnDownloadTextDocument"]= 'Last ned tekstdokument';
$l["cmdContactDetailsFor"]= 'Personopplysninger for';
$l["cmdLInkFieldset"]= 'Lenker';
$l["company"]= 'Firma';
$l["cmdCompanyDetailsFor"]= 'Opplysninger for';
$l["cmdPanelCompany"]= 'Firmaopplysninger';
$l["cmdFormLabelBankNo"]= 'Bankkonto';
$l["cmdFormLabelVatNo"]= 'Org.nr.';
$l["cmdFieldsetCompanyDetails"]= 'Firmaopplysninger';
$l["cmdFieldsetVisitAddress"]= 'Besøksadresse';
$l["cmdFieldsetPostAddress"]= 'Postadresse';
$l["cmdCompanyDialog"]= 'Rediger firma';
$l["cmdPanelEmployees"]= 'Ansatte';
$l["cmdPanelEmployee"]= 'Ansatt';
$l["cmdAllEmployeesForThisCompany"]= 'Alle ansatte i dette firmaet';
$l["cmdFieldsetVisitAddress"]= 'Besøksadresse';
$l["cmdFieldsetPostAddress"]= 'Postadresse';
$l["cmdManageDialog"]= 'Behandle';
$l["cmdAddAddressBook"]= 'Ny adressebok';
$l["cmdDeleteAddressbook"]= 'Slett adressebok';
$l["cmdOwner"]= 'Eier';
$l["cmdPanelAddressbook"]= 'Adressebøker';
$l["cmdPanelProperties"]= 'Egenskaper';
$l["cmdContactDialog"]= 'Rediger kontaktperson';
$l["cmdFormLabelFileType"]= 'Filtype';
$l["cmdFormLabelFile"]= 'Fil';	;
$l["cmdFormLabelValueSeperated"]= 'Feltgrense';
$l["cmdFormLabelValueIncluded"]= 'Tekstgrense';
$l["cmdFormLabelLinesEnded"]= 'Linjer slutter med';
$l["cmdUpload"]= 'Last opp';
$l["cmdImport"]= 'Importer';
$l["cmdExport"]= 'Eksporter';
$l["cmdType"]= 'Type';
$l["contacts"]= 'Kontaktpersoner';
$l["companies"]= 'Firmaer';
$l["users"]= 'Brukere';
$l["strSelectContact"]= 'Velg kontaktperson';
$l["strSelectCompany"]= 'Velg firma';
$l["noAddressbooks"]= 'Det finnes ingen adressebøker';
$l["moveAll"]= 'Firmaet og alle ansatte vil også flyttes til den nye adresseboken. Er du sikker på at du ønsker å gjøre dette?';
$l["addressbook"]= 'Adressebok';
$l["addressbooks"]= 'Adressebøker';
$l["sendMailing"]='Masseutsendelse';
$l["importSuccess"]='Data er importert!';
$l["searchOnSender"]='Oppslag i adressebok';
$l["confirmCreate"]='Kontaktperson finnes ikke. Vil du opprette en ny kontaktperson?';
$l["matchFields"]='Finn like felter';
$l["advancedSearch"]='Avansert søk';
$l["defaultAddressFormat"]='Forvalgt adresseformat';
$l["defaultSalutation"]='Forvalgt hilsning';
$l["explanationVariables"]='Forklaring til hilsningsvariabler';
$l["explanationSex"]='Mannlig og kvinnelig hilsningsform';
$l["newSearch"]='Nytt søk';
$l["executeQuery"]='Kjør søk';
$l["savedQueries"]='Lagrede søk';
$l["selectField"]= 'Velg felt';
$l["searchQueryName"]='Navn på søk';
$l["enterSearchQueryName"]='Angi et navn for dette søket:';
$l["photo"]= 'Bilde';
$l["deleteImage"]='Slett bilde';
$l["addAllSearchResults"]='Legg til alle søkeresultater';
$l["confirmAddAllSearchResults"]='Er du sikker på at du vil legge alle søkeresultatene til adresselisten?';
$l["moveEmployees"]='Flytt ansatte';
$l["id"]='ID';
$l["emailAdded"]='E-postadressen ble lagret på kontaktpersonen';
$l["exportWithCompanies"]='Med firmaer';
$l["exportPermission"]='Eksporttillatelser';
$l["crn"]='CRN';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Ukjent e-postadresse';
$l["strUnknownEmail"]= 'Ukjent e-postadresse. Vil du legge den til en ny kontaktperson, oppdatere en eksisterende kontaktperson, eller avbryte?';
$l["globalsettings_templatelabel"]= 'Mal';
$l["globalsettings_allchangelabel"]= 'Endre alle?';
$l["globalsettings_renameall"]= 'Gi nytt navn til alle?';
$l["createEmailSelected"]= 'Lag e-post til utvalg';
$l['addresslists']='Addresselister';
$l['sendingEmailAllowed']='Kan motta masseutsendelser';
$l["cmdFormLabelInvoiceEmail"]= 'Faktura e-postadresse';
$l['contact']= 'Kontaktperson';
$l['company']= 'Firma';
$l['defaultSalutationTpl']='Kjære {middle_name} {last_name}';
$l['no_addressbook_id']= 'Ugyldig addressebok-ID ble sendt til serveren!';
$l['undefined']= '-';
$l['createUser']='Lag bruker';
$l['addresslist']= 'Adresseliste';
$l['addresslistContact']= 'Adresseliste kontaktperson';
$l["emailTemplate"]= 'E-postmal';
$l["cmdPanelTemplate"]= 'Maler';
$l["cmdAddEmailTemplate"]= 'Ny e-postmal';
$l["addDocumentTemplate"]='Ny dokumentmal';
$l["documentTemplate"]='Dokumentmal';
$l["unsubscribeLink"]='Avmeldingslenke';
$l["unsubscribeHref"]='Avmelding href';
$l["autoDataMyName"]= 'Mitt navn';
$l["autoDataBeginning"]= 'Innledning';
$l["autoData"]= 'Autodata';
$l["customContactFields"]='Egendefinerte felt kontaktpersoner';
$l["customCompanyFields"]='Egendefinerte felt firmaer';
$l["customUserFields"]='Egendefinerte felt brukere';
$l["cmdAddOpenOfficeTemplate"]= 'Ny ODF-mal';
$l["cmdTemplateDialog"]= 'Rediger mal';
$l["cmdFormLabelReadNotification"]= 'Be mottageren om lesebrekreftelse';
$l["cmdAddMailing"]= 'Ny adresseliste';
$l["cmdDeleteMailing"]= 'Slett adresseliste';
$l["cmdPanelMailings"]= 'Adresselister';
$l["cmdEditMailingWindow"]= 'Rediger adresseliste';
$l["SelectOODocument"]= 'Velg mal';
$l["SelectOODocumentWindowTitle"]= 'Velg ODF-dokument';
$l["sendingEmailAllowed"]= 'Det er tillat å sende e-post til denne adressen';
$l["enabledMailingGroups"]= 'Aktiverte adresselister:';
$l["noMailingGroups"]='Du har ingen addesselister';
$l["sentMailings"]='Sendte nyhetsbrev';
$l["subject"]='Emne';
$l["status"]='Status';
$l["sent"]='Sendt';
$l["total"]='Totalt';
$l["errors"]='Feil';
$l["addEntireAddressbook"]='Legg til en hel adressebok';
$l["selectAddressbook"]='Velg en adressebok';
$l["defaultSalutationText"]='Angi en hilsning som skal brukes når det ikke er angitt noen spesiell hilsning for mottagerne';
$l["filterMailings"]='Adresseliste filter';
$l["enterName"]='Angi filnavn';
$l["pleaseEnterName"]='Du må angi et filnavn for det nye dokumentet!';
$l["noAddressLists"]='Ingen adresselister';
$l["confirmAddEntireAddressbook"]='Er du sikker på at du vil legge til alle i denne adresseboken til denne adresselisten?';
$l["noTemplate"]='Ingen mal';
$l["newsletters"]='Nyhetsbrev';
$l["addresslist"]='Adresselist';
$l["viewLog"]='Vis logg';
$l["viewMessage"]='Vis melding';
$l["pauseMailing"]='Pause utsendelse';
$l["resumeMailing"]='Fortsett utsendelse';
$l["copyingMessages"]='Kopierer meldinger...';
$l["companyId"]= "ID";
$l["companyUser_id"]= "Bruker";
$l["companyAddressbook_id"]= "Adressebok";
$l["companyName"]= "Navn";
$l["companyName2"]= "Navn 2";
$l["companyAddress"]= "Adresse1";
$l["companyAddress_no"]= "Adresse2";
$l["companyZip"]= "Postnummer";
$l["companyCity"]= "Sted";
$l["companyState"]= "Delstat/region";
$l["companyCountry"]= "Land";
$l["companyPost_address"]= "Post adresse1";
$l["companyPost_address_no"]= "Post adresse2";
$l["companyPost_city"]= "Post sted";
$l["companyPost_state"]= "Post delstat/region";
$l["companyPost_country"]= "Post Land";
$l["companyPost_zip"]= "Post postnummer";
$l["companyPhone"]= "Telefon";
$l["companyFax"]= "Fax";
$l["companyEmail"]= "E-post";
$l["companyHomepage"]= "Nettsted";
$l["companyComment"]= "Kommentarer";
$l["companyBank_no"]= "Bankkonto";
$l["companyVat_no"]= "Org.nr.";
$l["companyIban"]= "IBAN";
$l["companyCrn"]= "CRN";
$l["companyCtime"]= "Opprettet dato";
$l["companyMtime"]= "Endret dato";
$l["companyEmail_allowed"]= "E-post tillatt";
$l["companyFiles_folder_id"]= "Mappe";
$l["contactId"]= "ID";
$l["contactUser_id"]= "Bruker";
$l["contactAddressbook_id"]= "Adressebok";
$l["contactFirst_name"]= "Fornavn";
$l["contactMiddle_name"]= "Mellomnavn";
$l["contactLast_name"]= "Etternavn";
$l["contactInitials"]= "Initialer";
$l["contactTitle"]= "Tittel";
$l["contactSex"]= "Kjønn";
$l["contactBirthday"]= "Fødselsdag";
$l["contactEmail"]= "E-post";
$l["contactEmail2"]= "E-post2";
$l["contactEmail3"]= "E-post3";
$l["contactCompany_id"]= "Firma";
$l["contactDepartment"]= "Avdeling";
$l["contactFunction"]= "Funksjon";
$l["contactHome_phone"]= "Telefon (Hjem)";
$l["contactWork_phone"]= "Telefon (Arbeid)";
$l["contactFax"]= "Fax (Hjem)";
$l["contactWork_fax"]= "Fax (Arbeid)";
$l["contactCellular"]= "Mobil";
$l["contactCountry"]= "Land";
$l["contactState"]= "Delstat/region";
$l["contactCity"]= "Sted";
$l["contactZip"]= "Postnummer";
$l["contactAddress"]= "Adresse";
$l["contactAddress_no"]= "Adresse2r";
$l["contactComment"]= "Kommentarer";
$l["contactCtime"]= "Opprettet";
$l["contactMtime"]= "Endret";
$l["contactSalutation"]= "Hilsning";
$l["contactEmail_allowed"]= "E-post tillatt";
$l["contactFiles_folder_id"]= "Mappe";
$l["contactGo_user_id"]= "Bruker";
$l['mailingStatus'][0]="Venter på å starte";
$l['mailingStatus'][1]="Kjører";
$l['mailingStatus'][2]="Fullført";
$l['mailingStatus'][3]="Pauset";
$l['status']='Status';
$l['templateAlreadyExists']= 'Malen du prøver å opprette eksisterer allerede';
$l['mailingAlreadyExists']= 'Masseutsendelsen du prøver å opprette eksisterer allerede';
$l['greet']='Med vennlig hilsen';
$l['unsubscribe']='Meld av';
$l['unsubscription']='Klikk her for å melde deg av denne adresselisten.';
$l['r_u_sure']= 'Er du sikker på at du vil melde deg av adresselisten?';
$l['delete_success']= 'Du er nå fjernet fra denne adresselisten.';
$l['setCurrentTemplateAsDefault']='Sett denne malen som standard';
$l['contactCustomFields']='Egendefinerte felt kontaktpersoner';
$l['companyCustomFields']='Egendefinerte felt firmaer';
$l['editUser']='Rediger bruker';
$l['templateContent']='Dokument';
$l['addresslistIdMustBePositive']='Dette panelet forventer en adresseliste-ID som er positiv, men fikk ikke dette. Vennligst kontakt administrator.';
$l["importSuccessCount"]='Importerte poster:';
$l['male']='Mann';
$l['female']='Kvinne';
$l['importing']='Importerer';

==> groupoffice-com-4.0.97.tar.gz: groupoffice-com-4.0.97/modules/addressbook/language/nb.php <==
<?php




$l['name'] = 'Adressebok';
$l['description'] = 'Modul for å håndtere alle kontakter.';
$l['allAddressbooks'] = 'Alle adressebøker';
$l['notIncluded'] = 'Ikke importer';
$l['comment'] = 'Kommentar';
$l['bankNo'] = 'Bankkonto'; ;
$l['vatNo'] = 'Org.nr.';
$l['contactsGroup'] = 'Gruppe';
$l['customers'] = 'Kunder';
$l['suppliers'] = 'Leverandører';
$l['prospects'] = 'Prospekter';
$l['contacts'] = 'Kontaktpersoner';
$l['companies'] = 'Firmaer';
$l['newContactAdded']='Ny kontaktperson er lagt til';
$l['newContactFromSite']='En ny kontaktperson er lagt til via et nettstedskjema.';
$l['clickHereToView']='Trykk her for å vise kontakpersonen';
$l['contactFromAddressbook']='Kontaktperson fra %s';
$l['companyFromAddressbook']='Firma fra %s';
$l['multipleSelected']='Flere adressebøker er valgt';
$l['incomplete_delete_contacts']='Du har ikke rettigheter til å slette alle valgte kontaktpersoner';
$l['incomplete_delete_companies']='Du har ikke rettigheter til å slette alle valgte firmaer';
$l['emailAlreadyExists']='E-postadressen er allerede lagret på denne kontaktpersonen';
$l['emailDoesntExists']='Fant ikke e-postadressen';
$l['imageNotSupported']='Bildefilen du lastet opp er ikke støttet. Bare gif, png og jpg er gyldige filtyper.';
$l["selectMailingGroup"]='Velg gruppe for masseutsendelse';
$l["cmdFormLabelAddressBooks"]= 'Adressebok';
$l["alphabet"]= 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,Æ,Ø,Å';
$l["cmdAllFields"]= 'Alle felt';
$l["btnAddContact"]= 'Ny kontaktperson'	;
$l["btnAddCompany"]= 'Nytt firma';
$l["btnManage"]= 'Behandle';
$l["btnDownload"]= 'Last ned fil';
$l["cmdFormSearchFirst"]= 'Søk i= ';
$l["cmdFormSearchSecond"]= ' på= ';
$l["cmdFormSearchThird"]= ' for= ';
$l["cmdFormSearchFourth"]= '(Bruk \'%\' som jokertegn) ';
$l["cmdFormLabelTitleInitials"]= 'Tittel/initialer';
$l["cmdFormLabelSalutation"]= 'Hilsning';
$l["cmdFormLabelComment"]= 'Kommentarer';
$l["cmdFormCompanyEmptyText"]= 'Velg et firma';
$l["cmdFieldsetSelectAddressbook"]= 'Velg adressebok';
$l["cmdFieldsetPersonalDetails"]= 'Personlige opplysninger';
$l["cmdFieldsetAddress"]= 'Adresse';
$l["cmdFieldsetContact"]= 'Kontaktopplysninger';
$l["cmdFieldsetWork"]= 'Arbeid';
$l["cmdPanelContact"]= 'Kontaktopplysninger';
$l["cmdPanelComments"]= 'Kommentarer';
$l["cmdContactDialog"]= 'Rediger kontaktperson';
$l["contact"]= 'Kontaktperson';
$l["cmdSalutation"]= 'Kjære';
$l["cmdMadam"]= 'fr.';
$l["cmdSir"]= 'herr';
$l["btnDownloadTextDocument"]= 'Last ned tekstdokument';
$l["cmdContactDetailsFor"]= 'Personopplysninger for';
$l["cmdLInkFieldset"]= 'Lenker';
$l["company"]= 'Firma';
$l["cmdCompanyDetailsFor"]= 'Opplysninger for';
$l["cmdPanelCompany"]= 'Firmaopplysninger';
$l["cmdFormLabelBankNo"]= 'Bankkonto';
$l["cmdFormLabelVatNo"]= 'Org.nr.';
$l["cmdFieldsetCompanyDetails"]= 'Firmaopplysninger';
$l["cmdFieldsetVisitAddress"]= 'Besøksadresse';
$l["cmdFieldsetPostAddress"]= 'Postadresse';
$l["cmdCompanyDialog"]= 'Rediger firma';
$l["cmdPanelEmployees"]= 'Ansatte';
$l["cmdPanelEmployee"]= 'Ansatt';
$l["cmdAllEmployeesForThisCompany"]= 'Alle ansatte i dette firmaet';
$l["cmdFieldsetVisitAddress"]= 'Besøksadresse';
$l["cmdFieldsetPostAddress"]= 'Postadresse';
$l["cmdManageDialog"]= 'Behandle';
$l["cmdAddAddressBook"]= 'Ny adressebok';
$l["cmdDeleteAddressbook"]= 'Slett adressebok';
$l["cmdOwner"]= 'Eier';
$l["cmdPanelAddressbook"]= 'Adressebøker';
$l["cmdPanelProperties"]= 'Egenskaper';
$l["cmdContactDialog"]= 'Rediger kontaktperson';
$l["cmdFormLabelFileType"]= 'Filtype';
$l["cmdFormLabelFile"]= 'Fil';	;
$l["cmdFormLabelValueSeperated"]= 'Feltgrense';
$l["cmdFormLabelValueIncluded"]= 'Tekstgrense';
$l["cmdFormLabelLinesEnded"]= 'Linjer slutter med';
$l["cmdUpload"]= 'Last opp';
$l["cmdImport"]= 'Importer';
$l["cmdExport"]= 'Eksporter';
$l["cmdType"]= 'Type';
$l["contacts"]= 'Kontaktpersoner';
$l["companies"]= 'Firmaer';
$l["users"]= 'Brukere';
$l["strSelectContact"]= 'Velg kontaktperson';
$l["strSelectCompany"]= 'Velg firma';
$l["noAddressbooks"]= 'Det finnes ingen adressebøker';
$l["moveAll"]= 'Firmaet og alle ansatte vil også flyttes til den nye adresseboken. Er du sikker på at du ønsker å gjøre dette?';
$l["addressbook"]= 'Adressebok';
$l["addressbooks"]= 'Adressebøker';
$l["sendMailing"]='Masseutsendelse';
$l["importSuccess"]='Data er importert!';
$l["searchOnSender"]='Oppslag i adressebok';
$l["confirmCreate"]='Kontaktperson finnes ikke. Vil du opprette en ny kontaktperson?';
$l["matchFields"]='Finn like felter';
$l["advancedSearch"]='Avansert søk';
$l["defaultAddressFormat"]='Forvalgt adresseformat';
$l["defaultSalutation"]='Forvalgt hilsning';
$l["explanationVariables"]='Forklaring til hilsningsvariabler';
$l["explanationSex"]='Mannlig og kvinnelig hilsningsform';
$l["newSearch"]='Nytt søk';
$l["executeQuery"]='Kjør søk';
$l["savedQueries"]='Lagrede søk';
$l["selectField"]= 'Velg felt';
$l["searchQueryName"]='Navn på søk';
$l["enterSearchQueryName"]='Angi et navn for dette søket:';
$l["photo"]= 'Bilde';
$l["deleteImage"]='Slett bilde';
$l["addAllSearchResults"]='Legg til alle søkeresultater';
$l["confirmAddAllSearchResults"]='Er du sikker på at du vil legge alle søkeresultatene til adresselisten?';
$l["moveEmployees"]='Flytt ansatte';
$l["id"]='ID';
$l["emailAdded"]='E-postadressen ble lagret på kontaktpersonen';
$l["exportWithCompanies"]='Med firmaer';
$l["exportPermission"]='Eksporttillatelser';
$l["crn"]='CRN';
$l["iban"]='IBAN';
$l["unknownEmail"]= 'Ukjent e-postadresse';
$l["strUnknownEmail"]= 'Ukjent e-postadresse. Vil du legge den til en ny kontaktperson, oppdatere en eksisterende kontaktperson, eller avbryte?';
$l["globalsettings_templatelabel"]= 'Mal';
$l["globalsettings_allchangelabel"]= 'Endre alle?';
$l["globalsettings_renameall"]= 'Gi nytt navn til alle?';
$l["createEmailSelected"]= 'Lag e-post til utvalg';
$l['addresslists']='Addresselister';
$l['sendingEmailAllowed']='Kan motta masseutsendelser';
$l["cmdFormLabelInvoiceEmail"]= 'Faktura e-postadresse';
$l['contact']= 'Kontaktperson';
$l['company']= 'Firma';
$l['defaultSalutationTpl']='Kjære {middle_name} {last_name}';
$l['no_addressbook_id']= 'Ugyldig addressebok-ID ble sendt til serveren!';
$l['undefined']= '-';
$l['createUser']='Lag bruker';
$l['addresslist']= 'Adresseliste';
$l['addresslistContact']= 'Adresseliste kontaktperson';
$l["emailTemplate"]= 'E-postmal';
$l["cmdPanelTemplate"]= 'Maler';
$l["cmdAddEmailTemplate"]= 'Ny e-postmal';
$l["addDocumentTemplate"]='Ny dokumentmal';
$l["documentTemplate"]='Dokumentmal';
$l["unsubscribeLink"]='Avmeldingslenke';
$l["unsubscribeHref"]='Avmelding href';
$l["autoDataMyName"]= 'Mitt navn';
$l["autoDataBeginning"]= 'Innledning';
$l["autoData"]= 'Autodata';
$l["customContactFields"]='Egendefinerte felt kontaktpersoner';
$l["customCompanyFields"]='Egendefinerte felt firmaer';
$l["customUserFields"]='Egendefinerte felt brukere';
$l["cmdAddOpenOfficeTemplate"]= 'Ny ODF-mal';
$l["cmdTemplateDialog"]= 'Rediger mal';
$l["cmdFormLabelReadNotification"]= 'Be mottageren om lesebrekreftelse';
$l["cmdAddMailing"]= 'Ny adresseliste';
$l["cmdDeleteMailing"]= 'Slett adresseliste';
$l["cmdPanelMailings"]= 'Adresselister';
$l["cmdEditMailingWindow"]= 'Rediger adresseliste';
$l["SelectOODocument"]= 'Velg mal';
$l["SelectOODocumentWindowTitle"]= 'Velg ODF-dokument';
$l["sendingEmailAllowed"]= 'Det er tillat å sende e-post til denne adressen';
$l["enabledMailingGroups"]= 'Aktiverte adresselister:';
$l["noMailingGroups"]='Du har ingen addesselister';
$l["sentMailings"]='Sendte nyhetsbrev';
$l["subject"]='Emne';
$l["status"]='Status';
$l["sent"]='Sendt';
$l["total"]='Totalt';
$l["errors"]='Feil';
$l["addEntireAddressbook"]='Legg til en hel adressebok';
$l["selectAddressbook"]='Velg en adressebok';
$l["defaultSalutationText"]='Angi en hilsning som skal brukes når det ikke er angitt noen spesiell hilsning for mottagerne';
$l["filterMailings"]='Adresseliste filter';
$l["enterName"]='Angi filnavn';
$l["pleaseEnterName"]='Du må angi et filnavn for det nye dokumentet!';
$l["noAddressLists"]='Ingen adresselister';
$l["confirmAddEntireAddressbook"]='Er du sikker på at du vil legge til alle i denne adresseboken til denne adresselisten?';
$l["noTemplate"]='Ingen mal';
$l["newsletters"]='Nyhetsbrev';
$l["addresslist"]='Adresselist';
$l["viewLog"]='Vis logg';
$l["viewMessage"]='Vis melding';
$l["pauseMailing"]='Pause utsendelse';
$l["resumeMailing"]='Fortsett utsendelse';
$l["copyingMessages"]='Kopierer meldinger...';
$l["companyId"]= "ID";
$l["companyUser_id"]= "Bruker";
$l["companyAddressbook_id"]= "Adressebok";
$l["companyName"]= "Navn";
$l["companyName2"]= "Navn 2";
$l["companyAddress"]= "Adresse1";
$l["companyAddress_no"]= "Adresse2";
$l["companyZip"]= "Postnummer";
$l["companyCity"]= "Sted";
$l["companyState"]= "Delstat/region";
$l["companyCountry"]= "Land";
$l["companyPost_address"]= "Post adresse1";
$l["companyPost_address_no"]= "Post adresse2";
$l["companyPost_city"]= "Post sted";
$l["companyPost_state"]= "Post delstat/region";
$l["companyPost_country"]= "Post Land";
$l["companyPost_zip"]= "Post postnummer";
$l["companyPhone"]= "Telefon";
$l["companyFax"]= "Fax";
$l["companyEmail"]= "E-post";
$l["companyHomepage"]= "Nettsted";
$l["companyComment"]= "Kommentarer";
$l["companyBank_no"]= "Bankkonto";
$l["companyVat_no"]= "Org.nr.";
$l["companyIban"]= "IBAN";
$l["companyCrn"]= "CRN";
$l["companyCtime"]= "Opprettet dato";
$l["companyMtime"]= "Endret dato";
$l["companyEmail_allowed"]= "E-post tillatt";
$l["companyFiles_folder_id"]= "Mappe";
$l["contactId"]= "ID";
$l["contactUser_id"]= "Bruker";
$l["contactAddressbook_id"]= "Adressebok";
$l["contactFirst_name"]= "Fornavn";
$l["contactMiddle_name"]= "Mellomnavn";
$l["contactLast_name"]= "Etternavn";
$l["contactInitials"]= "Initialer";
$l["contactTitle"]= "Tittel";
$l["contactSex"]= "Kjønn";
$l["contactBirthday"]= "Fødselsdato";
$l["contactEmail"]= "E-post";
$l["contactEmail2"]= "E-post2";
$l["contactEmail3"]= "E-post3";
$l["contactCompany_id"]= "Firma";
$l["contactDepartment"]= "Avdeling";
$l["contactFunction"]= "Funksjon";
$l["contactHome_phone"]= "Telefon (Hjem)";
$l["contactWork_phone"]= "Telefon (Arbeid)";
$l["contactFax"]= "Fax (Hjem)";
$l["contactWork_fax"]= "Fax (Arbeid)";
$l["contactCellular"]= "Mobil";
$l["contactCountry"]= "Land";
$l["contactState"]= "Delstat/region";
$l["contactCity"]= "Sted";
$l["contactZip"]= "Postnummer";
$l["contactAddress"]= "Adresse";
$l["contactAddress_no"]= "Adresse2r";
$l["contactComment"]= "Kommentarer";
$l["contactCtime"]= "Opprettet";
$l["contactMtime"]= "Endret";
$l["contactSalutation"]= "Hilsning";
$l["contactEmail_allowed"]= "E-post tillatt";
$l["contactFiles_folder_id"]= "Mappe";
$l["contactGo_user_id"]= "Bruker";
$l['mailingStatus'][0]="Venter på å starte";
$l['mailingStatus'][1]="Kjører";
$l['mailingStatus'][2]="Fullført";
$l['mailingStatus'][3]="Pauset";
$l['status']='Status';
$l['templateAlreadyExists']= 'Malen du prøver å opprette eksisterer allerede';
$l['mailingAlreadyExists']= 'Masseutsendelsen du prøver å opprette eksisterer allerede';
$l['greet']='Med vennlig hilsen';
$l['unsubscribe']='Meld av';
$l['unsubscription']='Klikk her for å melde deg av denne adresselisten.';
$l['r_u_sure']= 'Er du sikker på at du vil melde deg av adresselisten?';
$l['delete_success']= 'Du er nå fjernet fra denne adresselisten.';
$l['setCurrentTemplateAsDefault']='Sett denne malen som standard';
$l['contactCustomFields']='Egendefinerte felt kontaktpersoner';
$l['companyCustomFields']='Egendefinerte felt firmaer';
$l['editUser']='Rediger bruker';
$l['templateContent']='Dokument';
$l['addresslistIdMustBePositive']='Dette panelet forventer en adresseliste-ID som er positiv, men fikk ikke dette. Vennligst kontakt administrator.';
$l["importSuccessCount"]='Importerte poster:';
$l['male']='Mann';
$l['female']='Kvinne';
$l['importing']='Importerer';
$l['contactUuid']='UUID';
$l['nRemovedFromAddresslist']='%n kontakter er identifisert, og fjernet fra valgte adresseliste.';
